<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

class Chatty_Actions {

	public function __construct() {

		add_action( 'wp_ajax_nopriv_chatty_get', array( $this, 'get_messages' ) );
		add_action( 'wp_ajax_chatty_get', array( $this, 'get_messages' ) );

		add_action( 'wp_ajax_nopriv_chatty_post', array( $this, 'save_messages' ) );
		add_action( 'wp_ajax_chatty_post', array( $this, 'save_messages' ) );

	}

	// Save messages via AJAX
	public function save_messages() {

		// Check if nonce is present
		check_ajax_referer( 'chatty_nonce', 'nonce' );
		
		$msg_content = sanitize_text_field( $_POST['msg'] );
		$msg_author = sanitize_text_field( $_POST['author'] );
		$msg_time = sanitize_text_field( $_POST['time'] );
		$msg_user_id = sanitize_text_field( $_POST['uid'] );
		
		$chat_id = absint( $_POST['id'] );
		
		$chatty_msgs = get_option( 'chatty-chat-' . $chat_id, array() );
		
		$chatty_msgs[] = array( 
							'a'  => $msg_author,
							'm'  => $msg_content,
							't'  => $msg_time,
							'av' => get_avatar( $msg_user_id, 32 ),
						);
		
		$response = update_option( 'chatty-chat-' . $chat_id, $chatty_msgs );
		
		wp_send_json( $response );

	}

	public function get_messages() {

		// Check if nonce is present
		check_ajax_referer( 'chatty_nonce', 'nonce' );
		
		$chat_id = absint( $_POST['id'] );
		
		$response = Chatty_Content_Output::chatty_output( $chat_id );
		
		wp_send_json( $response );

	}

}

new Chatty_Actions();